@@ -9,6 +9,15 @@ if [ "$(uname -m)" = "armv8" ] || [ "$(uname -m)" = "ppc64le" ]; then
     CPU_COUNT=$(grep -c ^processor /proc/cpuinfo)
 fi
 
+if [ "$(uname)" = "Darwin" ]; then
+    # unset macosx-version-min hardcoded in clang CPPFLAGS
+    export CPPFLAGS="$(echo ${CPPFLAGS:-} | sed -E 's@\-mmacosx\-version\-min=[^ ]*@@g')"
+    export CPPFLAGS="${CPPFLAGS} -D_DARWIN_C_SOURCE"
+    echo "CPPFLAGS=$CPPFLAGS"
+fi
+
+echo "sysroot: ${CONDA_BUILD_SYSROOT:-unset}"
+
 # The without snapshot comes from the error in
 # https://github.com/nodejs/node/issues/4212.
 ./configure --prefix=$PREFIX --without-snapshot
